@@ -3,10 +3,10 @@
 #==============================================================================
 # Demonstrates the use of embedded windows in tablelist widgets.
 #
-# Copyright (c) 2004-2016  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2004-2017  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-package require tablelist_tile 5.16
+package require tablelist_tile 6.0
 
 wm title . "Tile Library Scripts"
 
@@ -77,7 +77,15 @@ ttk::scrollbar $vsb -orient vertical -command [list $tbl yview]
 
 proc emptyStr val { return "" }
 
-eval font create BoldFont [font actual [$tbl cget -font]] -weight bold
+#
+# Create a bold font
+#
+set tblFont [$tbl cget -font]
+set size [font actual $tblFont -size]
+if {$size == 0} {					;# e.g., on Ubuntu
+    set size -12
+}
+eval font create BoldFont [font actual $tblFont] -size $size -weight bold
 
 #
 # Populate the tablelist widget
@@ -87,15 +95,19 @@ if {[info exists ttk::library]} {
 } else {
     cd $tile::library
 }
-set maxFileSize 0
+set totalSize 0
+set maxSize 0
 foreach fileName [lsort [glob *.tcl]] {
     set fileSize [file size $fileName]
     $tbl insert end [list $fileName $fileSize $fileSize "" no]
 
-    if {$fileSize > $maxFileSize} {
-	set maxFileSize $fileSize
+    incr totalSize $fileSize
+    if {$fileSize > $maxSize} {
+	set maxSize $fileSize
     }
 }
+$tbl header insert 0 [list "[$tbl size] *.tcl files" "" $totalSize "" ""]
+$tbl header rowconfigure 0 -foreground blue
 
 #------------------------------------------------------------------------------
 # createFrame
@@ -124,7 +136,7 @@ proc createFrame {tbl row col w} {
     # Manage the child frame
     #
     set fileSize [$tbl cellcget $row,fileSize -text]
-    place $w.f -relwidth [expr {double($fileSize) / $::maxFileSize}]
+    place $w.f -relwidth [expr {double($fileSize) / $::maxSize}]
 }
 
 #------------------------------------------------------------------------------
@@ -142,7 +154,7 @@ proc createButton {tbl row col w} {
 #------------------------------------------------------------------------------
 # viewFile
 #
-# Displays the contents of the file whose name is contained in the row with the
+# Displays the content of the file whose name is contained in the row with the
 # given key of the tablelist widget tbl.
 #------------------------------------------------------------------------------
 proc viewFile {tbl key} {
@@ -169,7 +181,7 @@ proc viewFile {tbl key} {
     ttk::scrollbar $vsb -orient vertical -command [list $txt yview]
 
     #
-    # Insert the file's contents into the text widget
+    # Insert the file's content into the text widget
     #
     set chan [open $fileName]
     $txt insert end [read $chan]
