@@ -7,7 +7,7 @@
 #   - Private procedures implementing the interactive cell editing
 #   - Private procedures used in bindings related to interactive cell editing
 #
-# Copyright (c) 2003-2016  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2003-2017  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
 #
@@ -22,6 +22,7 @@ namespace eval tablelist {
     #
     proc addTkCoreWidgets {} {
 	variable editWin
+	variable pu
 
 	set name entry
 	array set editWin [list \
@@ -47,9 +48,9 @@ namespace eval tablelist {
 	array set editWin [list \
 	    $name-creationCmd	"$name %W -padx 2 -pady 2 -wrap none" \
 	    $name-putValueCmd	"%W delete 1.0 end; %W insert 1.0 %T" \
-	    $name-getValueCmd	"%W get 1.0 end-1c" \
+	    $name-getValueCmd	"%W get 1.0 end-1$pu" \
 	    $name-putTextCmd	"%W delete 1.0 end; %W insert 1.0 %T" \
-	    $name-getTextCmd	"%W get 1.0 end-1c" \
+	    $name-getTextCmd	"%W get 1.0 end-1$pu" \
 	    $name-putListCmd	"" \
 	    $name-getListCmd	"" \
 	    $name-selectCmd	"" \
@@ -564,12 +565,13 @@ proc tablelist::addCtext {{name ctext}} {
     checkEditWinName $name
 
     variable editWin
+    variable pu
     array set editWin [list \
 	$name-creationCmd	"ctext %W -padx 2 -pady 2 -wrap none" \
 	$name-putValueCmd	"%W delete 1.0 end; %W insert 1.0 %T" \
-	$name-getValueCmd	"%W get 1.0 end-1c" \
+	$name-getValueCmd	"%W get 1.0 end-1$pu" \
 	$name-putTextCmd	"%W delete 1.0 end; %W insert 1.0 %T" \
-	$name-getTextCmd	"%W get 1.0 end-1c" \
+	$name-getTextCmd	"%W get 1.0 end-1$pu" \
 	$name-putListCmd	"" \
 	$name-getListCmd	"" \
 	$name-selectCmd		"" \
@@ -1075,54 +1077,11 @@ proc tablelist::checkEditWinName name {
 #------------------------------------------------------------------------------
 # tablelist::createCheckbutton
 #
-# Creates a checkbutton widget with the given path name for interactive cell
+# Creates a checkbutton widget of the given path name for interactive cell
 # editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createCheckbutton {w args} {
-    variable winSys
-    switch $winSys {
-	x11 {
-	    variable checkedImg
-	    variable uncheckedImg
-	    if {![info exists checkedImg]} {
-		createCheckbuttonImgs 
-	    }
-
-	    checkbutton $w -borderwidth 2 -indicatoron 0 -image $uncheckedImg \
-			   -selectimage $checkedImg
-	    if {$::tk_version >= 8.4} {
-		$w configure -offrelief sunken
-	    }
-	    pack $w
-	}
-
-	win32 {
-	    checkbutton $w -borderwidth 0 -font {"MS Sans Serif" 8} \
-			   -padx 0 -pady 0
-	    [winfo parent $w] configure -width 13 -height 13
-	    switch [winfo reqheight $w] {
-		17	{ set y -1 }
-		20	{ set y -3 }
-		25	{ set y -5 }
-		30 -
-		31	{ set y -8 }
-		default	{ set y -1 }
-	    }
-	    place $w -x -1 -y $y
-	}
-
-	classic {
-	    checkbutton $w -borderwidth 0 -font "system" -padx 0 -pady 0
-	    [winfo parent $w] configure -width 16 -height 14
-	    place $w -x 0 -y -1
-	}
-
-	aqua {
-	    checkbutton $w -borderwidth 0 -font "system" -padx 0 -pady 0
-	    [winfo parent $w] configure -width 16 -height 16
-	    place $w -x -4 -y -3
-	}
-    }
+    makeCheckbutton $w
 
     foreach {opt val} $args {
 	switch -- $opt {
@@ -1138,7 +1097,7 @@ proc tablelist::createCheckbutton {w args} {
 #------------------------------------------------------------------------------
 # tablelist::createMenubutton
 #
-# Creates a menubutton widget with the given path name for interactive cell
+# Creates a menubutton widget of the given path name for interactive cell
 # editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createMenubutton {w args} {
@@ -1223,7 +1182,7 @@ proc tablelist::postMenuCmd w {
 #------------------------------------------------------------------------------
 # tablelist::createTileEntry
 #
-# Creates a tile entry widget with the given path name for interactive cell
+# Creates a tile entry widget of the given path name for interactive cell
 # editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createTileEntry {w args} {
@@ -1274,7 +1233,7 @@ proc tablelist::createTileEntry {w args} {
 #------------------------------------------------------------------------------
 # tablelist::createTileSpinbox
 #
-# Creates a tile spinbox widget with the given path name for interactive cell
+# Creates a tile spinbox widget of the given path name for interactive cell
 # editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createTileSpinbox {w args} {
@@ -1332,7 +1291,7 @@ proc tablelist::createTileSpinbox {w args} {
 #------------------------------------------------------------------------------
 # tablelist::createTileCombobox
 #
-# Creates a tile combobox widget with the given path name for interactive cell
+# Creates a tile combobox widget of the given path name for interactive cell
 # editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createTileCombobox {w args} {
@@ -1358,30 +1317,11 @@ proc tablelist::createTileCombobox {w args} {
 #------------------------------------------------------------------------------
 # tablelist::createTileCheckbutton
 #
-# Creates a tile checkbutton widget with the given path name for interactive
-# cell editing in a tablelist widget.
+# Creates a tile checkbutton widget of the given path name for interactive cell
+# editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createTileCheckbutton {w args} {
-    if {$::tk_version < 8.5 || [regexp {^8\.5a[1-5]$} $::tk_patchLevel]} {
-	package require tile 0.6
-    }
-    createTileAliases 
-
-    #
-    # Define the checkbutton layout; use catch to suppress
-    # the error message in case the layout already exists
-    #
-    set currentTheme [getCurrentTheme]
-    if {[string compare $currentTheme "aqua"] == 0} {
-	catch {style layout Tablelist.TCheckbutton { Checkbutton.button }}
-    } else {
-	catch {style layout Tablelist.TCheckbutton { Checkbutton.indicator }}
-	styleConfig Tablelist.TCheckbutton -indicatormargin 0
-    }
-
-    set win [getTablelistPath $w]
-    ttk::checkbutton $w -style Tablelist.TCheckbutton \
-			-variable ::tablelist::ns${win}::data(editText)
+    makeTileCheckbutton $w
 
     foreach {opt val} $args {
 	switch -- $opt {
@@ -1390,121 +1330,15 @@ proc tablelist::createTileCheckbutton {w args} {
 	}
     }
 
-    #
-    # Adjust the dimensions of the tile checkbutton's parent
-    # and manage the checkbutton, depending on the current theme
-    #
-    switch -- $currentTheme {
-	aqua {
-	    [winfo parent $w] configure -width 16 -height 16
-	    place $w -x -3 -y -3
-	}
-
-	Aquativo {
-	    [winfo parent $w] configure -width 14 -height 14
-	    place $w -x -1 -y -1
-	}
-
-	blue -
-	winxpblue {
-	    set height [winfo reqheight $w]
-	    [winfo parent $w] configure -width $height -height $height
-	    place $w -x 0
-	}
-
-	clam {
-	    [winfo parent $w] configure -width 11 -height 11
-	    place $w -x 0
-	}
-
-	keramik -
-	keramik_alt {
-	    [winfo parent $w] configure -width 16 -height 16
-	    place $w -x -1 -y -1
-	}
-
-	plastik {
-	    [winfo parent $w] configure -width 15 -height 15
-	    place $w -x -2 -y 1
-	}
-
-	sriv -
-	srivlg {
-	    [winfo parent $w] configure -width 15 -height 16
-	    place $w -x -1
-	}
-
-	tileqt {
-	    switch -- [string tolower [tileqt_currentThemeName]] {
-		acqua {
-		    [winfo parent $w] configure -width 17 -height 18
-		    place $w -x -1 -y -2
-		}
-		cde -
-		cleanlooks -
-		motif {
-		    [winfo parent $w] configure -width 13 -height 13
-		    if {[info exists ::env(KDE_SESSION_VERSION)] &&
-			[string length $::env(KDE_SESSION_VERSION)] != 0} {
-			place $w -x -2
-		    } else {
-			place $w -x 0
-		    }
-		}
-		gtk+ {
-		    [winfo parent $w] configure -width 15 -height 15
-		    place $w -x -1 -y -1
-		}
-		kde_xp {
-		    [winfo parent $w] configure -width 13 -height 13
-		    place $w -x 0
-		}
-		keramik -
-		thinkeramik {
-		    [winfo parent $w] configure -width 16 -height 16
-		    place $w -x 0
-		}
-		oxygen {
-		    [winfo parent $w] configure -width 17 -height 17
-		    place $w -x -2 -y -1
-		}
-		default {
-		    set height [winfo reqheight $w]
-		    [winfo parent $w] configure -width $height -height $height
-		    place $w -x 0
-		}
-	    }
-	}
-
-	vista {
-	    set height [winfo reqheight $w]
-	    [winfo parent $w] configure -width $height -height $height
-	    place $w -x 0
-	}
-
-	winnative -
-	xpnative {
-	    set height [winfo reqheight $w]
-	    [winfo parent $w] configure -width $height -height $height
-	    if {[info exists tile::patchlevel] &&
-		[string compare $tile::patchlevel "0.8.0"] < 0} {
-		place $w -x -2
-	    } else {
-		place $w -x 0
-	    }
-	}
-
-	default {
-	    pack $w
-	}
-    }
+    set win [getTablelistPath $w]
+    $w configure -variable ::tablelist::ns${win}::data(editText)
 }
 
 #------------------------------------------------------------------------------
 # tablelist::createTileMenubutton
 #
-# Creates a tile menubutton widget with the given path name for interactive
-# cell editing in a tablelist widget.
+# Creates a tile menubutton widget of the given path name for interactive cell
+# editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createTileMenubutton {w args} {
     if {$::tk_version < 8.5 || [regexp {^8\.5a[1-5]$} $::tk_patchLevel]} {
@@ -1551,8 +1385,8 @@ proc tablelist::createTileMenubutton {w args} {
 #------------------------------------------------------------------------------
 # tablelist::createBWidgetComboBox
 #
-# Creates a BWidget ComboBox widget with the given path name for interactive
-# cell editing in a tablelist widget.
+# Creates a BWidget ComboBox widget of the given path name for interactive cell
+# editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createBWidgetComboBox {w args} {
     eval [list ComboBox $w -editable 1 -width 0] $args
@@ -1568,7 +1402,7 @@ proc tablelist::createBWidgetComboBox {w args} {
 #------------------------------------------------------------------------------
 # tablelist::createIncrCombobox
 #
-# Creates an [incr Widgets] combobox with the given path name for interactive
+# Creates an [incr Widgets] combobox of the given path name for interactive
 # cell editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createIncrCombobox {w args} {
@@ -1590,8 +1424,8 @@ proc tablelist::createIncrCombobox {w args} {
 #------------------------------------------------------------------------------
 # tablelist::createOakleyCombobox
 #
-# Creates an Oakley combobox widget with the given path name for interactive
-# cell editing in a tablelist widget.
+# Creates an Oakley combobox widget of the given path name for interactive cell
+# editing in a tablelist widget.
 #------------------------------------------------------------------------------
 proc tablelist::createOakleyCombobox {w args} {
     eval [list combobox::combobox $w -editable 1 -width 0] $args
@@ -1649,7 +1483,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
     seeCell $win $row $col
     set netRowHeight [lindex [bboxSubCmd $win $row] 3]
     set frameHeight [expr {$netRowHeight + 6}]	;# because of the -pady -3 below
-    set f $data(bodyFr)
+    set f $data(bodyFrm)
     tk::frame $f -borderwidth 0 -container 0 -height $frameHeight \
 		 -highlightthickness 0 -relief flat -takefocus 0
     catch {$f configure -padx 0 -pady 0}
@@ -1659,7 +1493,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
     set creationCmd [strMap {"%W" "$w"} $editWin($name-creationCmd)]
     append creationCmd { $editWin($name-fontOpt) [getCellFont $win $key $col]} \
 		       { -state normal}
-    set w $data(bodyFrEd)
+    set w $data(bodyFrmEd)
     if {[catch {eval $creationCmd} result] != 0} {
 	destroy $f
 	return -code error $result
@@ -1712,17 +1546,18 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
     }
 
     #
-    # Replace the cell's contents between the two tabs with the above frame
+    # Replace the cell's content between the two tabs with the above frame
     #
     array set data [list editKey $key editRow $row editCol $col]
-    findTabs $win [expr {$row + 1}] $col $col tabIdx1 tabIdx2
     set b $data(body)
+    findTabs $win $b [expr {$row + 1}] $col $col tabIdx1 tabIdx2
     getIndentData $win $data(editKey) $data(editCol) indentWidth
+    variable pu
     if {$indentWidth == 0} {
-	set textIdx [$b index $tabIdx1+1c]
+	set textIdx [$b index $tabIdx1+1$pu]
     } else {
-	$b mark set editIndentMark [$b index $tabIdx1+1c]
-	set textIdx [$b index $tabIdx1+2c]
+	$b mark set editIndentMark [$b index $tabIdx1+1$pu]
+	set textIdx [$b index $tabIdx1+2$pu]
     }
     if {$isCheckbtn} {
 	set editIdx $textIdx
@@ -1733,12 +1568,12 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 	    set editIdx $textIdx
 	    $b delete $editIdx $tabIdx2
 	} elseif {[string compare $alignment "right"] == 0} {
-	    $b mark set editAuxMark $tabIdx2-1c
+	    $b mark set editAuxMark $tabIdx2-1$pu
 	    set editIdx $textIdx
-	    $b delete $editIdx $tabIdx2-1c
+	    $b delete $editIdx $tabIdx2-1$pu
 	} else {
 	    $b mark set editAuxMark $textIdx
-	    set editIdx [$b index $textIdx+1c]
+	    set editIdx [$b index $textIdx+1$pu]
 	    $b delete $editIdx $tabIdx2
 	}
     }
@@ -1770,7 +1605,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 	restoreEditData $win
     } else {
 	#
-	# Put the cell's contents to the edit window
+	# Put the cell's content to the edit window
 	#
 	set data(canceled) 0
 	set data(invoked) 0
@@ -1791,6 +1626,9 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 	if {[string length $data(-editstartcommand)] != 0} {
 	    set text [uplevel #0 $data(-editstartcommand) \
 		      [list $win $row $col $text]]
+	    if {[destroyed $win]} {
+		return ""
+	    }
 
 	    variable winSys
 	    if {[string compare $winSys "aqua"] == 0} {
@@ -1958,10 +1796,10 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
     if {$isText} {
 	if {[string compare [$w cget -wrap] "none"] == 0 ||
 	    $::tk_version < 8.5} {
-	    set numLines [expr {int([$w index end-1c])}]
+	    set numLines [expr {int([$w index end-1$pu])}]
 	    $w configure -height $numLines
 	    update idletasks				;# needed for ctext
-	    if {![array exists ::tablelist::ns${win}::data]} {
+	    if {[destroyed $win]} {
 		return ""
 	    }
 	    $f configure -height [winfo reqheight $w]
@@ -1977,7 +1815,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 	}
     } elseif {!$isCheckbtn} {
 	update idletasks
-	if {![array exists ::tablelist::ns${win}::data]} {
+	if {[destroyed $win]} {
 	    return ""
 	}
 	$f configure -height [winfo reqheight $w]
@@ -1990,7 +1828,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 	place $w -relwidth 1.0 -relheight 1.0
 	adjustEditWindow $win $pixels
 	update idletasks
-	if {![array exists ::tablelist::ns${win}::data]} {
+	if {[destroyed $win]} {
 	    return ""
 	}
     }
@@ -2003,7 +1841,7 @@ proc tablelist::doEditCell {win row col restore {cmd ""} {charPos -1}} {
 # tablelist::doCancelEditing
 #
 # Processes the tablelist cancelediting subcommand.  Aborts the interactive
-# cell editing and restores the cell's contents after destroying the edit
+# cell editing and restores the cell's content after destroying the edit
 # window.
 #------------------------------------------------------------------------------
 proc tablelist::doCancelEditing win {
@@ -2021,10 +1859,13 @@ proc tablelist::doCancelEditing win {
 	[string length $data(-editendcommand)] != 0} {
 	uplevel #0 $data(-editendcommand) \
 		[list $win $row $col $data(origEditText)]
+	if {[destroyed $win]} {
+	    return ""
+	}
     }
 
-    if {[winfo exists $data(bodyFr)]} {
-	destroy $data(bodyFr)
+    if {[winfo exists $data(bodyFrm)]} {
+	destroy $data(bodyFrm)
 	set item [lindex $data(itemList) $row]
 	set key [lindex $item end]
 	foreach opt {-window -image} {
@@ -2064,7 +1905,7 @@ proc tablelist::doFinishEditing win {
     # Get the edit window's text, and invoke the command
     # specified by the -editendcommand option if needed
     #
-    set w $data(bodyFrEd)
+    set w $data(bodyFrmEd)
     set name [getEditWindow $win $row $col]
     variable editWin
     set text [eval [strMap {"%W" "$w"} $editWin($name-getTextCmd)]]
@@ -2081,6 +1922,9 @@ proc tablelist::doFinishEditing win {
 	if {[string length $data(-editendcommand)] != 0} {
 	    set text \
 		[uplevel #0 $data(-editendcommand) [list $win $row $col $text]]
+	    if {[destroyed $win]} {
+		return 0
+	    }
 	}
     }
 
@@ -2089,7 +1933,7 @@ proc tablelist::doFinishEditing win {
     # statement or within the command specified by the -editendcommand option)
     #
     if {$data(rejected)} {
-	if {[winfo exists $data(bodyFr)]} {
+	if {[winfo exists $data(bodyFrm)]} {
 	    seeCell $win $row $col
 	    if {[string compare [winfo class $w] "Mentry"] != 0} {
 		focus $data(editFocus)
@@ -2101,8 +1945,8 @@ proc tablelist::doFinishEditing win {
 	set data(rejected) 0
 	set result 0
     } else {
-	if {[winfo exists $data(bodyFr)]} {
-	    destroy $data(bodyFr)
+	if {[winfo exists $data(bodyFrm)]} {
+	    destroy $data(bodyFrm)
 	    set key [lindex $item end]
 	    foreach opt {-window -image} {
 		if {[info exists data($key,$col$opt)]} {
@@ -2156,7 +2000,8 @@ proc tablelist::adjustTextHeight {w args} {
 	#
 	# We can only count the logical lines (irrespective of wrapping)
 	#
-	set numLines [expr {int([$w index end-1c])}]
+	variable pu
+	set numLines [expr {int([$w index end-1$pu])}]
     }
     $w configure -height $numLines
 
@@ -2281,7 +2126,7 @@ proc tablelist::adjustEditWindow {win pixels} {
     set name [getEditWindow $win $data(editRow) $data(editCol)]
     variable editWin
     if {$editWin($name-useReqWidth) &&
-	[set reqWidth [winfo reqwidth $data(bodyFrEd)]] <=
+	[set reqWidth [winfo reqwidth $data(bodyFrmEd)]] <=
 	$pixels + 2*$data(charWidth)} {
 	set width $reqWidth
 	set padX [expr {$reqWidth <= $pixels ? -3 : ($pixels - $reqWidth) / 2}]
@@ -2305,7 +2150,7 @@ proc tablelist::adjustEditWindow {win pixels} {
 	set padX -$amount
     }
 
-    $data(bodyFr) configure -width $width
+    $data(bodyFrm) configure -width $width
     $data(body) window configure editMark -padx $padX
 }
 
@@ -2325,9 +2170,9 @@ proc tablelist::setEditWinFont win {
 
     set key [lindex $data(keyList) $data(editRow)]
     set cellFont [getCellFont $win $key $data(editCol)]
-    $data(bodyFrEd) configure $editWin($name-fontOpt) $cellFont
+    $data(bodyFrmEd) configure $editWin($name-fontOpt) $cellFont
 
-    $data(bodyFr) configure -height [winfo reqheight $data(bodyFrEd)]
+    $data(bodyFrm) configure -height [winfo reqheight $data(bodyFrmEd)]
 }
 
 #------------------------------------------------------------------------------
@@ -2337,7 +2182,7 @@ proc tablelist::setEditWinFont win {
 #------------------------------------------------------------------------------
 proc tablelist::saveEditData win {
     upvar ::tablelist::ns${win}::data data
-    set w $data(bodyFrEd)
+    set w $data(bodyFrmEd)
     set entry $data(editFocus)
     set class [winfo class $w]
     set isText [expr {[string compare $class "Text"] == 0 ||
@@ -2445,7 +2290,7 @@ proc tablelist::saveEditConfigOpts w {
 #------------------------------------------------------------------------------
 proc tablelist::restoreEditData win {
     upvar ::tablelist::ns${win}::data data
-    set w $data(bodyFrEd)
+    set w $data(bodyFrmEd)
     set entry $data(editFocus)
     set class [winfo class $w]
     set isText [expr {[string compare $class "Text"] == 0 ||
